Module data_table

Module data_table 

Module for building DataTable block.

Re-exports

pub use crate::blocks::table::RawText;

Modules

builders
Builders for DataTable related objects.

Structs

DataTable
Data Table block representation.
DataTableBuilder
Builder for DataTable object.
DataTableRow
Single table row representation being set to the rows field in DataTable object.
RawNumber
A raw number table cell value which can be used in DataTable block.

Enums

DataTableCell
A table cell for DataTable block.