pub struct DataTableRow { /* private fields */ }Expand description
Single table row representation being set to the rows field in DataTable
object.
Table rows contain an array of table cells, each represented by
DataTableCell enum.
Fields and Validations
| Field | Type | Required | Validation |
|---|---|---|---|
| cells | Vec<DataTableCell> | Yes | Maximum of 20 items. |
Example
use slack_messaging::blocks::RichText;
use slack_messaging::blocks::rich_text::RichTextSection;
use slack_messaging::blocks::rich_text::types::{RichTextElementText, RichTextStyle};
use slack_messaging::blocks::data_table::DataTableRow;
let row = DataTableRow::builder()
.cell("Data Refinement Department")
.cell("MDR")
.cell(
RichText::builder()
.element(
RichTextSection::builder()
.element(
RichTextElementText::builder()
.text("Blue")
.style(
RichTextStyle::builder()
.bold(true)
.build()?
)
.build()?
)
.build()?
)
.build()?
)
.build()?;
let expected = serde_json::json!([
{
"type": "raw_text",
"text": "Data Refinement Department"
},
{
"type": "raw_text",
"text": "MDR"
},
{
"type": "rich_text",
"elements": [
{
"type": "rich_text_section",
"elements": [
{
"type": "text",
"text": "Blue",
"style": {
"bold": true
}
}
]
}
]
}
]);
let json = serde_json::to_value(row).unwrap();
assert_eq!(json, expected);Implementations
Sourceimpl DataTableRow
impl DataTableRow
Sourcepub fn builder() -> DataTableRowBuilder
pub fn builder() -> DataTableRowBuilder
constract DataTableRowBuilder object.