pub struct RichTextQuote { /* private fields */ }Expand description
Rich text quote element representation.
Fields and Validations
For more details, see the official documentation.
| Field | Type | Required | Validation |
|---|---|---|---|
| elements | Vec<RichTextElementType> | Yes | N/A |
| border | i64 | No | N/A |
Example
use slack_messaging::blocks::rich_text::prelude::*;
let quote = RichTextQuote::builder()
.element(
RichTextElementText::builder()
.text("What we need is good examples in our documentation.")
.build()?
)
.border(0)
.build()?;
let expected = serde_json::json!({
"type": "rich_text_quote",
"elements": [
{
"type": "text",
"text": "What we need is good examples in our documentation."
}
],
"border": 0
});
let json = serde_json::to_value(quote).unwrap();
assert_eq!(json, expected);
// If your object has any validation errors, the build method returns Result::Err
let quote = RichTextQuote::builder().build();
assert!(quote.is_err());Implementations
Sourceimpl RichTextQuote
impl RichTextQuote
Sourcepub fn builder() -> RichTextQuoteBuilder
pub fn builder() -> RichTextQuoteBuilder
constract RichTextQuoteBuilder object.