OptGroup

Struct OptGroup 

pub struct OptGroup<T = PlainText>
where T: TextExt,
{ /* private fields */ }
Option group object representation.

This is a generic struct that can represent an option group object with different text object types.

Type Parameters

  • T: The type of text object used for the text field of the Opt objects in the options field. Defaults to PlainText. Must implement the TextExt trait.

Fields and Validations

For more details, see the official documentation.

FieldTypeRequiredValidation
label[Text]<[Plain]>YesMax length 75 characters
optionsVec<Opt<T>>YesMust contain at most 100 items

Example

use slack_messaging::plain_text;
use slack_messaging::composition_objects::{OptGroup, Opt, PlainText};

let options: OptGroup = OptGroup::builder()
    .label(plain_text!("Group One")?)
    .option(
        Opt::builder()
            .text(plain_text!("option-0")?)
            .value("value-0")
            .build()?
    )
    .option(
        Opt::builder()
            .text(plain_text!("option-1")?)
            .value("value-1")
            .build()?
    )
    .build()?;

let expected = serde_json::json!({
    "label": {
        "type": "plain_text",
        "text": "Group One"
    },
    "options": [
        {
            "text": {
                "type": "plain_text",
                "text": "option-0",
            },
            "value": "value-0"
        },
        {
            "text": {
                "type": "plain_text",
                "text": "option-1"
            },
            "value": "value-1"
        },
    ]
});

let json = serde_json::to_value(options).unwrap();

assert_eq!(json, expected);

// If your object has any validation errors, the build method returns Result::Err
let options = OptGroup::<PlainText>::builder()
    .label(plain_text!("Group One")?)
    .build();

assert!(options.is_err());

Implementations

Source

impl<T> OptGroup<T>
where T: TextExt,

pub fn builder() -> OptGroupBuilder<T>

constract OptGroupBuilder object.