pub struct TextObject<T> { /* private fields */ }Expand description
Text object representation.
This is a generic struct that can represent either a plain text object or a markdown text
object, depending on the type parameter T.
Type Parameters
Fields and Validations
For more details, see the Slack API documentation.
TextObject<Plain> or alias PlainText
| Field | Type | Required | Validation |
|---|---|---|---|
| text | String | Yes | Minimum length: 1 character, Maximum length: 3000 characters. |
| emoji | bool | No | N/A |
TextObject<Mrkdwn> or alias MrkdwnText
| Field | Type | Required | Validation |
|---|---|---|---|
| text | String | Yes | Minimum length: 1 character, Maximum length: 3000 characters. |
| verbatim | bool | No | N/A |
Example
use slack_messaging::composition_objects::{PlainText, MrkdwnText};
// 1. Plain Text Object
let plain_text = PlainText::builder()
.text("Hello, World!")
.emoji(true)
.build()?;
let plain_json = serde_json::to_value(plain_text).unwrap();
let expected_plain = serde_json::json!({
"type": "plain_text",
"text": "Hello, World!",
"emoji": true
});
assert_eq!(plain_json, expected_plain);
// 2. Markdown Text Object
let mrkdwn_text = MrkdwnText::builder()
.text("*Hello*, _World_!")
.verbatim(false)
.build()?;
let mrkdwn_json = serde_json::to_value(mrkdwn_text).unwrap();
let expected_mrkdwn = serde_json::json!({
"type": "mrkdwn",
"text": "*Hello*, _World_!",
"verbatim": false
});
assert_eq!(mrkdwn_json, expected_mrkdwn);Implementations
Sourceimpl<T> TextObject<T>
impl<T> TextObject<T>
Sourcepub fn builder() -> TextObjectBuilder<T>
pub fn builder() -> TextObjectBuilder<T>
constract TextObjectBuilder object.