Module for building DataTable block.
Re-exports
pub use crate::blocks::table::RawText;
Modules
Structs
- Data
Table - Data Table block representation.
- Data
Table Builder - Builder for
DataTableobject. - Data
Table Row - Single table row representation being set to the rows field in
DataTableobject. - RawNumber
- A raw number table cell value which can be used in DataTable block.
Enums
- Data
Table Cell - A table cell for DataTable block.