pub enum ValidationErrorKind {
Show 18 variants
Required,
MaxTextLength(usize),
MinTextLength(usize),
MaxArraySize(usize),
MinArraySize(usize),
EmptyArray,
InvalidFormat(&'static str),
MaxIntegerValue(i64),
MinIntegerValue(i64),
MustBeGreaterThanZero,
ExclusiveField(&'static str, &'static str),
EitherRequired(&'static str, &'static str),
AtLeastOneOf4(&'static str, &'static str, &'static str, &'static str),
NoFieldProvided,
RichTextSingleElement,
RichTextTableHeader,
UniqueSeriesName,
DataPointLabelMatching,
}Expand description
Validation error variants.
Variants
Required
Field is required but not provided.
MaxTextLength(usize)
Field exceeds maximum text length.
MinTextLength(usize)
Field does not meet minimum text length.
MaxArraySize(usize)
Field exceeds maximum array length.
MinArraySize(usize)
Field does not meet minimum array length.
EmptyArray
Field does not meet non-empty condition.
InvalidFormat(&'static str)
Field does not meet format condition.
MaxIntegerValue(i64)
Field exceeds maximum integer value.
MinIntegerValue(i64)
Field does not meet minimum integer value.
MustBeGreaterThanZero
Field must be greater than zero.
ExclusiveField(&'static str, &'static str)
Both fields are provided but only one is allowed.
EitherRequired(&'static str, &'static str)
Either field is required but none is provided.
AtLeastOneOf4(&'static str, &'static str, &'static str, &'static str)
NoFieldProvided
At least one field is required but none is provided.
RichTextSingleElement
Rich text block should have exactly one element.
RichTextTableHeader
Rich text cannot be used for a table header row.
UniqueSeriesName
Each series within a chart must have a unique name.
DataPointLabelMatching
Every data point label in every series must match a value in axis config categories.